@@ -23,7 +23,7 @@ namespace Tellico {
  */
 class UPCValidator : public TQValidator {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   UPCValidator(TQObject* parent, const char* name=0);
@@ -37,11 +37,14 @@ signals:
   void signalISBN();
 
 private:
-  State decodeCat(TQString& str) const;
-
   bool m_checkISBN : 1;
   mutable bool m_isbn : 1;
 };
 
+class CueCat {
+public:
+  static TQValidator::State decode(TQString& str);
+};
+
 } // end namespace
 #endif
